---
name: Feature request
about: Suggest an idea for this project
title: FR
labels: enhancement
assignees: ''

---

**Describe the feature you'd like to add**
A clear and concise description of what you want to happen.

**Additional context**
Add optionally, any other context or screenshots about the feature request here.
